package websocket

import (
	"encoding/json"
	"git.smsvc.net/pomodoro/GoTomato/internal/pomodoro"
	"git.smsvc.net/pomodoro/GoTomato/internal/shared"
	"git.smsvc.net/pomodoro/GoTomato/pkg/models"
	"github.com/gorilla/websocket"
	"log"
)

// handleClientCommands listens for commands from WebSocket clients
func handleClientCommands(ws *websocket.Conn) {
	for {
		var clientCommand models.ClientCommand

		_, message, err := ws.ReadMessage()
		if err != nil {
			log.Printf("Client disconnected from %s (%v) (total: %d)", ws.NetConn().RemoteAddr(), err, len(Clients)-1)
			delete(Clients, ws)
			break
		}

		// Handle incoming commands
		err = json.Unmarshal(message, &clientCommand)
		if err != nil {
			log.Printf("Error unmarshalling command: %v", err)
			continue
		}

		// Process the command if pomodoro password matches
		if clientCommand.Password == shared.PomodoroPassword {
			switch clientCommand.Command {
			case "start":
				if !pomodoro.IsPomodoroOngoing() {
					go pomodoro.RunPomodoro() // Start the timer with the list of clients
				}
			case "stop":
				if pomodoro.IsPomodoroOngoing() {
					pomodoro.ResetPomodoro() // Reset Pomodoro
				}
			case "pause":
				if pomodoro.IsPomodoroOngoing() && !pomodoro.IsPomodoroPaused() {
					pomodoro.PausePomodoro() // Pause the timer
				}
			case "resume":
				if pomodoro.IsPomodoroOngoing() && pomodoro.IsPomodoroPaused() {
					pomodoro.ResumePomodoro() // Resume the timer
				}
			case "updateSettings":
				if !pomodoro.IsPomodoroOngoing() {
					if clientCommand.PomodoroSettings != (models.GoTomatoPomodoroConfig{}) {
						shared.Message.PomodoroSettings = clientCommand.PomodoroSettings
						shared.Message.TimeLeft = clientCommand.PomodoroSettings.Work
					}

				}
			}
		}

	}
}
